@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11609 2019-06-04 18:15:07Z Lavender $
+# $Id: __init__.py 11627 2019-06-10 19:47:08Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-06-05 03:15:07 +0900 (週三, 05 六月 2019) $
-# $Revision: 11609 $
+# $Date: 2019-06-11 04:47:08 +0900 (週二, 11 六月 2019) $
+# $Revision: 11627 $
 
 import os
 import sys
+import base64 
 import warnings
 import json
 import six
@@ -30,6 +31,7 @@ from collections import OrderedDict
 import twder
 
 from Iuppiter.Encoding import utf8
+from Iuppiter.Encryption import Encryptor
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Iuno import warnWithout, update, require
 from Iuppiter.DjangoUtil import (extendInstalledApps, 
@@ -52,6 +54,8 @@ from Iuppiter.Logging import createLogger
 
 logger = createLogger(__name__)
 
+ENCRYPTION_KEY = "25025529"
+
 CKEDITOR_CONFIGS = {
     'default': {
         'skin': 'moono',
@@ -474,7 +478,7 @@ def attachShopURLs(settings, urlpatterns):
         # we are not used.
         url(r'^i18n/', include('django.conf.urls.i18n')),
         url(r'^shop/', shop.urls),
-        url(r'^basket/freeze/', views.freezeBasket, name="freezeBasket"),
+        url(r'^checkout/payment/redirect/', views.sendPaymentForm, name="formRedirect"),
     )
     
     ckeditorEnable = False
@@ -573,6 +577,7 @@ from django.conf import settings
 from django.template.loader import get_template
 from django.template import Context
 from django.utils.translation import ugettext_lazy as _
+from django.middleware.csrf import get_token
 from pyallpay import AllPay
 
 from Iuppiter.Encoding import utf8
@@ -710,6 +715,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
     backUrl = CLIENT_BACK_URL.replace(
                         'localhost:8000', domain).replace('http', scheme)
 
+    form = None
     # build form data
     if apiName == SPGATEWAY:
         data = {
@@ -742,9 +748,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
             context = Context({'spgateway': payment,})
         temp = get_template('shop/payment/Spgateway.html')
         form = temp.render(context)
-                                      
-        return form
-
+       
     if apiName in [ECPAY, ALLPAY]:
         data = {
             'TotalAmount': int(total), 
@@ -804,9 +808,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
                                     settings.ALLPAY_AUTO_SEND_FORM)
             form = form.replace(toBytes('allPay-Form'), toBytes('allpayForm'))
             form = form.replace(toBytes('allPayForm'), toBytes('allpayForm'))
-        
-        return form
-
+       
     if apiName == CATHAYBK:
         mpg = CathaybkAPI(
             merchantId=settings.CATHAYBK_API_MERCHANT_ID,
@@ -819,9 +821,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
         }
 
         form = mpg.buildForm(data)
-                                      
-        return form
-
+        
     if apiName == ECPAY_MAP:
         temp = get_template('shop/payment/EcpayMap.html')
 
@@ -872,9 +872,9 @@ def buildAPIForm(submission, request, apiName, extra={}):
                     default=str).replace("\"", "&quot;"),
             })
         form = temp.render(context)
-                                      
+        
         return form
-
+        
     if apiName == ECPAY_LOGISTIC and request.session.get('logisticMap'):
         mapData = json.loads(request.session['logisticMap'])
         
@@ -977,6 +977,41 @@ def buildAPIForm(submission, request, apiName, extra={}):
                 'data': data,
             })
         form = temp.render(context)
-
+        
         return form
-    return None
\ No newline at end of file
+        
+    if not form:
+        return None
+    else:      
+        """
+        if six.PY3:
+            if not isinstance(form, bytes):
+                form = str(form).encode()
+            encryptor = Encryptor(ENCRYPTION_KEY.encode())
+            formData = encryptor.encrypt(form)
+        else:
+            encryptor = Encryptor(ENCRYPTION_KEY)
+            formData = encryptor.encrypt(form)
+        """
+        
+        if not isinstance(form, bytes):
+            form = str(form).encode()
+            
+        form = base64.b64encode(form)
+            
+        temp = get_template('shop/payment/PaymentForm.html')
+        if DJANGO_VERSION >= 11100: # django >= 1.11
+            context = {
+                "csrf": get_token(request),
+                "formId": "%sForm" % apiName,
+                'formData': form,
+            }
+        else:
+            context = Context({
+                "csrf": get_token(request),
+                "formId": "%sForm" % apiName,
+                'formData': form,
+            })
+        form = temp.render(context)
+        
+        return form
\ No newline at end of file
