@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11609 2019-06-04 18:15:07Z Lavender $
+# $Id: views.py 11635 2019-06-12 07:29:45Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-05 03:15:07 +0900 (週三, 05 六月 2019) $
-# $Revision: 11609 $ 
+# $Date: 2019-06-12 16:29:45 +0900 (週三, 12 六月 2019) $
+# $Revision: 11635 $ 
 
 import json
 import logging
 import hashlib
+import base64
 import urllib
 import six
 
@@ -47,6 +48,7 @@ from phonenumber_field.phonenumber import to_python
 from oscar.core.compat import get_user_model
 
 from Iuppiter.Encoding import utf8
+from Iuppiter.Encryption import Encryptor
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Iuno.shop import forms
 from Iuno.shop import buildAPIForm
@@ -416,14 +418,19 @@ def returnCathaybkCreditXml(request):
 
         return HttpResponse(rtXml)
         
-@csrf_exempt       
-def freezeBasket(request):
+def sendPaymentForm(request):
     if request.method == 'POST':
+        formData = request.POST.get("formData")
         request.session['preBasketId'] = request.basket.id
         request.basket.freeze()
-        return HttpResponse("SUCCESS")
+        return render(
+                request, 
+                "shop/payment/PaymentRedirect.html", 
+                {'form': base64.b64decode(formData),}
+            )
     else:
-        return HttpResponse("ERROR")
+        return Http404
+    
 
 class SuccessResponseView2(_PaymentDetailsView):
     preview = True
@@ -439,10 +446,10 @@ class SuccessResponseView2(_PaymentDetailsView):
     def pre_conditions(self):
         return []
         
-    def load_frozen_basket(self, basket_id):
+    def loadFrozenBasket(self, basketId):
         # Lookup the frozen basket that this txn corresponds to
         try:
-            basket = Basket.objects.get(id=basket_id, status=Basket.FROZEN)
+            basket = Basket.objects.get(id=basketId, status=Basket.FROZEN)
         except Basket.DoesNotExist:
             return None
 
@@ -787,7 +794,20 @@ class SuccessResponseView2(_PaymentDetailsView):
                 }
                 return render(
                     request, 'shop/payment/LogisticRedirect.html', ctx)
-                    
+            
+            # ECPAY_LOGISTIC 不需要 loadFrozenBasket
+            if not self.apiName == ECPAY_LOGISTIC:
+                errorMsg = _(
+                    "A problem occurred communicating with %(apiName)s "
+                    "- please try again later"
+                ) % {"apiName": self.apiName}
+                self._basket = self.loadFrozenBasket(self.basketId)
+                if not self._basket:
+                    messages.error(self.request, errorMsg)
+                    return redirect('checkout:payment-details')
+            else:
+                self._basket = request.basket
+             
             return self.handle_place_order_submission(request)
         except Exception as e:
             # return msg
@@ -868,14 +888,8 @@ class SuccessResponseView2(_PaymentDetailsView):
         
         
     def build_submission(self, **kwargs):
-        errorMsg = _(
-            "A problem occurred communicating with PayPal "
-            "- please try again later"
-        )
-        kwargs['basket'] = self.load_frozen_basket(self.basketId)
-        if not kwargs['basket']:
-            messages.error(self.request, errorMsg)
-            
+        kwargs['basket'] = self._basket
+        
         submission = super(
             SuccessResponseView2, self).build_submission(**kwargs)
         
